#!/bin/sh

#################################################################
#
# name:    netstat port statistics writer
# version: 1.0
# date:    January 13, 2002
# author:  Devin Teske
#
# dependencies:
#
#      /bin/sh     netstat     cat     grep     uname
#
# The files `grep', `cat', and `netstat' all need to be in the
# execution path of the shell executing this script.
#
#################################################################

######################### Configuration options

# To configure nspsw edit the config file

config="./etc/netstat.conf";

######################### Begin script

# execute the configuration file
source $config;

# use netstat to look up the active connections
case `uname` in
Darwin)
   # Darwin has a non-GNU netstat
   ns=`/usr/sbin/netstat -n -f inet`;;
FreeBSD)
   # FreeBSD also has a non-GNU netstat
   ns=`netstat -n -f inet`;;
Linux)
   # GNU netstat
   ns=`netstat -nt`;;
*)
   # assume GNU netstat for everything else
   ns=`netstat -nt`;;
esac

# find out how manu users are connected
connected=`echo "$ns" | grep "EST" | grep -i -c "[:.]$uport "`;

# get a list of running file transfers
transfers=`echo "$ns" | grep "EST" | grep -i "[:.]$txport "`;

# find the column that contains "Send-Q" data
head=`echo "$ns" | grep -i "Send-Q"`;

# replace column names that have two words with one word
head=`echo "$head" | sed -e s/Local\ Address/L_Addr/`;
head=`echo "$head" | sed -e s/Foreign\ Address/F_Addr/`;

# count columns and find Send-Q
sq=0; ht=0; y=0;
for col in $head; do
   if [ $y -eq 0 ]; then
      ((sq=$sq+1));
   fi
   if [ "$col" = "Send-Q" -a $y -eq 0 ]; then
      y=1;
   fi
   ((ht=$ht+1));
done

# set initial variable values
downloads=0; uploads=0; z=0;

# loop through list of transfers counting up/down loads
for col in $transfers; do
   if [ $z -lt $ht ]; then
      ((z=$z+1));
   else
      z=1;
   fi
   if [ $z -eq $sq ]; then
      if [ "$col" = "0" ]; then
         ((uploads=$uploads+1));
      else
         ((downloads=$downloads+1));
      fi
   fi
done

# re-execute the conf file so it now knows these values
source $config;

# output the results
printf "$format";
